==> 20260228152955-1-001-crm25-25.0.0.zip: tests/Feature/ProfileUpdatesSettingsTest.php <==
<?php

namespace Tests\Feature;

use App\Models\UpdateCheck;
use App\Models\UpdateSetting;
use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Http;
use Tests\TestCase;

class ProfileUpdatesSettingsTest extends TestCase
{
    use RefreshDatabase;

    public function test_admin_can_open_updates_settings_tab_with_default_source(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        $this->actingAs($admin)
            ->get(route('profile.edit', ['section' => 'updates']))
            ->assertOk()
            ->assertSee('Updates')
            ->assertSee('update.crm25.webnet.kz');
    }

    public function test_admin_can_update_update_settings(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        $this->actingAs($admin)
            ->patch(route('profile.updates.update'), [
                'feed_url' => 'update.crm25.webnet.kz',
                'current_version' => '25.1.0',
                'channel' => 'beta',
                'is_active' => 1,
                'auto_check_enabled' => 1,
                'check_interval_minutes' => 360,
                'request_timeout_seconds' => 10,
                'verify_tls' => 1,
                '_settings_section' => 'updates',
            ])
            ->assertRedirect(route('profile.edit', ['section' => 'updates']))
            ->assertSessionHasNoErrors();

        $this->assertDatabaseHas('update_settings', [
            'feed_url' => 'https://update.crm25.webnet.kz',
            'current_version' => '25.1.0',
            'channel' => 'beta',
            'check_interval_minutes' => 360,
            'request_timeout_seconds' => 10,
        ]);
    }

    public function test_admin_can_run_update_check_and_store_result(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        UpdateSetting::query()->create([
            'feed_url' => 'https://update.crm25.webnet.kz',
            'current_version' => '25.0.0',
            'channel' => 'stable',
            'is_active' => true,
            'auto_check_enabled' => true,
            'check_interval_minutes' => 720,
            'request_timeout_seconds' => 8,
            'verify_tls' => true,
        ]);

        Http::fake([
            'https://update.crm25.webnet.kz/api/v1/crm25/updates*' => Http::response([
                'version' => '25.2.0',
                'build' => '250200',
                'is_update_available' => true,
                'notes' => 'New release available.',
            ], 200),
            '*' => Http::response(['message' => 'not used'], 404),
        ]);

        $this->actingAs($admin)
            ->post(route('profile.updates.check'))
            ->assertRedirect(route('profile.edit', ['section' => 'updates']))
            ->assertSessionHasNoErrors();

        $this->assertDatabaseHas('update_checks', [
            'status' => 'success',
            'remote_version' => '25.2.0',
            'is_update_available' => true,
        ]);

        $check = UpdateCheck::query()->latest('id')->first();
        $this->assertNotNull($check);
        $this->assertSame('https://update.crm25.webnet.kz/api/v1/crm25/updates', $check?->endpoint_url);
    }

    public function test_non_admin_cannot_manage_update_settings(): void
    {
        $user = User::factory()->create([
            'role' => 'user',
        ]);

        $this->actingAs($user)
            ->patch(route('profile.updates.update'), [
                'feed_url' => 'update.crm25.webnet.kz',
                'channel' => 'stable',
                'check_interval_minutes' => 720,
                'request_timeout_seconds' => 8,
            ])
            ->assertForbidden();

        $this->actingAs($user)
            ->post(route('profile.updates.check'))
            ->assertForbidden();
    }
}

==> 20260228233519-1-011-crm25-1.011.zip: tests/Feature/ProfileUpdatesSettingsTest.php <==
<?php

namespace Tests\Feature;

use App\Models\UpdateCheck;
use App\Models\UpdateInstallation;
use App\Models\UpdateSetting;
use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Http;
use Tests\TestCase;
use Tests\Concerns\BuildsUpdatePackages;

class ProfileUpdatesSettingsTest extends TestCase
{
    use RefreshDatabase;
    use BuildsUpdatePackages;

    public function test_admin_can_open_updates_settings_tab_with_default_source(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        $this->actingAs($admin)
            ->get(route('profile.edit', ['section' => 'updates']))
            ->assertOk()
            ->assertSee('Updates')
            ->assertSee('update.crm25.webnet.kz');
    }

    public function test_admin_can_update_update_settings(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        $this->actingAs($admin)
            ->patch(route('profile.updates.update'), [
                'feed_url' => 'update.crm25.webnet.kz',
                'current_version' => '25.1.0',
                'channel' => 'beta',
                'is_active' => 1,
                'auto_check_enabled' => 1,
                'check_interval_minutes' => 360,
                'request_timeout_seconds' => 10,
                'verify_tls' => 1,
                '_settings_section' => 'updates',
            ])
            ->assertRedirect(route('profile.edit', ['section' => 'updates']))
            ->assertSessionHasNoErrors();

        $this->assertDatabaseHas('update_settings', [
            'feed_url' => 'https://update.crm25.webnet.kz',
            'current_version' => '25.1.0',
            'channel' => 'beta',
            'check_interval_minutes' => 360,
            'request_timeout_seconds' => 10,
        ]);
    }

    public function test_admin_can_run_update_check_and_store_result(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        UpdateSetting::query()->create([
            'feed_url' => 'https://update.crm25.webnet.kz',
            'current_version' => '25.0.0',
            'channel' => 'stable',
            'is_active' => true,
            'auto_check_enabled' => true,
            'check_interval_minutes' => 720,
            'request_timeout_seconds' => 8,
            'verify_tls' => true,
        ]);

        Http::fake([
            'https://update.crm25.webnet.kz/api/v1/crm25/updates*' => Http::response([
                'version' => '25.2.0',
                'build' => '250200',
                'is_update_available' => true,
                'notes' => 'New release available.',
            ], 200),
            '*' => Http::response(['message' => 'not used'], 404),
        ]);

        $this->actingAs($admin)
            ->post(route('profile.updates.check'))
            ->assertRedirect(route('profile.edit', ['section' => 'updates']))
            ->assertSessionHasNoErrors();

        $this->assertDatabaseHas('update_checks', [
            'status' => 'success',
            'remote_version' => '25.2.0',
            'is_update_available' => true,
        ]);

        $check = UpdateCheck::query()->latest('id')->first();
        $this->assertNotNull($check);
        $this->assertSame('https://update.crm25.webnet.kz/api/v1/crm25/updates', $check?->endpoint_url);
    }

    public function test_non_admin_cannot_manage_update_settings(): void
    {
        $user = User::factory()->create([
            'role' => 'user',
        ]);

        $this->actingAs($user)
            ->patch(route('profile.updates.update'), [
                'feed_url' => 'update.crm25.webnet.kz',
                'channel' => 'stable',
                'check_interval_minutes' => 720,
                'request_timeout_seconds' => 8,
            ])
            ->assertForbidden();

        $this->actingAs($user)
            ->post(route('profile.updates.check'))
            ->assertForbidden();

        $this->actingAs($user)
            ->post(route('profile.updates.install'))
            ->assertForbidden();
    }

    public function test_admin_can_install_available_update_and_store_journal(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        UpdateSetting::query()->create([
            'feed_url' => 'https://update.crm25.webnet.kz',
            'current_version' => '1.001',
            'channel' => 'stable',
            'is_active' => true,
            'auto_check_enabled' => true,
            'check_interval_minutes' => 720,
            'request_timeout_seconds' => 8,
            'verify_tls' => true,
        ]);

        $targetPath = $this->createUpdateTargetFixture();
        $package = $this->createUpdatePackageFixture([
            'artisan' => "#!/usr/bin/env php\n<?php echo 'updated';\n",
            'config/app.php' => "<?php\n\nreturn ['name' => 'CRM25'];\n",
            'resources/fresh.txt' => 'new version',
        ]);

        config()->set('updates.target_path', $targetPath);
        config()->set('updates.storage_root', 'updates-testing-profile');
        config()->set('updates.run_post_install_commands', false);
        config()->set('updates.backup_enabled', true);

        $this->fakeAvailableUpdate($package['path'], $package['checksum']);

        $this->actingAs($admin)
            ->post(route('profile.updates.install'))
            ->assertRedirect(route('profile.edit', ['section' => 'updates']))
            ->assertSessionHasNoErrors();

        $this->assertDatabaseHas('update_installations', [
            'status' => 'installed',
            'target_version' => '1.002',
            'actor_id' => $admin->id,
        ]);

        $installation = UpdateInstallation::query()->latest('id')->first();
        $this->assertNotNull($installation);
        $this->assertNotNull($installation?->package_path);
        $this->assertNotNull($installation?->backup_path);
        $this->assertSame('1.002', UpdateSetting::query()->value('current_version'));
        $this->assertFileExists($targetPath.'/resources/fresh.txt');
        $this->assertFileDoesNotExist($targetPath.'/resources/obsolete.txt');
        $this->assertFileExists($targetPath.'/storage/app/crm-version');
        $this->assertSame('1.002', trim((string) File::get($targetPath.'/storage/app/crm-version')));

        File::deleteDirectory($targetPath);
        @unlink($package['path']);
    }

    public function test_admin_can_start_async_installation_and_poll_it(): void
    {
        $admin = User::factory()->create([
            'role' => 'admin',
        ]);

        UpdateSetting::query()->create([
            'feed_url' => 'https://update.crm25.webnet.kz',
            'current_version' => '1.003',
            'channel' => 'stable',
            'is_active' => true,
            'auto_check_enabled' => true,
            'check_interval_minutes' => 720,
            'request_timeout_seconds' => 8,
            'verify_tls' => true,
        ]);

        $response = $this->actingAs($admin)
            ->postJson(route('profile.updates.install'));

        $response
            ->assertAccepted()
            ->assertJsonPath('data.status', 'queued');

        $installationId = (int) $response->json('data.id');
        $this->assertGreaterThan(0, $installationId);

        $this->actingAs($admin)
            ->getJson(route('profile.updates.installations.show', ['installation' => $installationId]))
            ->assertOk()
            ->assertJsonPath('data.id', $installationId);
    }
}
